@@ -20,7 +20,7 @@
 
 package App::MtAws::ForkEngine;
 
-our $VERSION = '1.113';
+our $VERSION = '1.114';
 
 use strict;
 use warnings;
@@ -35,8 +35,7 @@ use App::MtAws::Utils;
 use App::MtAws::Exceptions;
 use POSIX;
 
-require Exporter;
-use base qw/Exporter/;
+use Exporter 'import';
 
 our @EXPORT_OK = qw/with_forks fork_engine/;
 
