@@ -20,7 +20,7 @@
 
 package App::MtAws::LineProtocol;
 
-our $VERSION = '1.113';
+our $VERSION = '1.114';
 
 use strict;
 use warnings;
@@ -30,8 +30,7 @@ use Carp;
 use JSON::XS;
 use App::MtAws::Utils;
 
-require Exporter;
-use base qw/Exporter/;
+use Exporter 'import';
 
 our @EXPORT = qw/ get_data send_data/;
 our @EXPORT_OK = qw/escape unescape encode_data decode_data/;
